@@ -37,19 +37,33 @@ def handler(event, context):
 
             while not found_component:
                 
-                response = ib_client.list_components(
-                    owner='Self',
-                    filters=[
-                        {
-                            'name': 'name',
-                            'values': [
-                                component_name,
-                            ]
-                        },
-                    ],
-                    maxResults=25,
-                    nextToken=next_token
-                )
+                if next_token:
+                    response = ib_client.list_components(
+                        owner='Self',
+                        filters=[
+                            {
+                                'name': 'name',
+                                'values': [
+                                    component_name,
+                                ]
+                            },
+                        ],
+                        maxResults=25,
+                        nextToken=next_token
+                    )
+                else:
+                    response = ib_client.list_components(
+                        owner='Self',
+                        filters=[
+                            {
+                                'name': 'name',
+                                'values': [
+                                    component_name,
+                                ]
+                            },
+                        ],
+                        maxResults=25
+                    )
                 
                 if 'componentVersionList' in response and len(response['componentVersionList']) > 0:
                     found_component = True
