@@ -16,6 +16,8 @@ This is a sample configuration:
 ---
 pipeline:
   parent_image: AmazonLinux2 # or Ubuntu2004 or CentOS7
+  cpu_type: X86_64 # or ARM_64. X86_64 is the default when the parameter is missing. ARM_64 doesn't work for CentOS 7 and is ignored.
+  iops: 3000 # Optional parameter to increase GP3 IOPS.
 
   sources: # Sources for use in the source stage of the Codepipeline.
     - name: Bucket
@@ -33,7 +35,10 @@ pipeline:
         - name: another_ec2_ib_component_from_github
         - name: install_nginx
   schedule: cron(0 4 1 * ? *)
-  shared_with: # Optional: Share images with another account. Image will be copied.
+  shared_with: # Optional: Share images with another account.
+    - region: eu-west-1
+      account_id: 123456789
+  copy_to: # Optional: Copy images to another account.
     - region: eu-west-1
       account_id: 123456789
 
@@ -212,14 +217,17 @@ class AmiPipelineLib(
     def get_lookup_criteria(
         self,
         parent_image: typing.Any,
+        cpu_type: builtins.str,
     ) -> _aws_cdk_aws_ec2_ceddda9d.LookupMachineImageProps:
         '''
         :param parent_image: -
+        :param cpu_type: -
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__c5336fb12ba611b64613dd41c3d0ef552b6d9390600e605567689ab05d57030e)
             check_type(argname="argument parent_image", value=parent_image, expected_type=type_hints["parent_image"])
-        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.LookupMachineImageProps, jsii.invoke(self, "getLookupCriteria", [parent_image]))
+            check_type(argname="argument cpu_type", value=cpu_type, expected_type=type_hints["cpu_type"])
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.LookupMachineImageProps, jsii.invoke(self, "getLookupCriteria", [parent_image, cpu_type]))
 
     @jsii.member(jsii_name="getNextRecipeVersion")
     def get_next_recipe_version(self, recipe_name: builtins.str) -> builtins.str:
@@ -1158,6 +1166,7 @@ def _typecheckingstub__8fa084614173e796293bce7073d0b702579254962fd4341864807d420
 
 def _typecheckingstub__c5336fb12ba611b64613dd41c3d0ef552b6d9390600e605567689ab05d57030e(
     parent_image: typing.Any,
+    cpu_type: builtins.str,
 ) -> None:
     """Type checking stubs"""
     pass
